==> eam-wshub-proxyclient-11.4-8-sources.jar: net/datastream/schemas/mp_fields/RISKMATRIXSETUPID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour RISKMATRIXSETUPID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="RISKMATRIXSETUPID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}RISKMATRIXSETUPCODE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DESCRIPTION" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "RISKMATRIXSETUPID_Type", propOrder = {
    "riskmatrixsetupcode",
    "description"
})
public class RISKMATRIXSETUPID_Type {

    @XmlElement(name = "RISKMATRIXSETUPCODE", required = true)
    protected String riskmatrixsetupcode;
    @XmlElement(name = "DESCRIPTION")
    protected String description;

    /**
     * Obtient la valeur de la propriété riskmatrixsetupcode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getRISKMATRIXSETUPCODE() {
        return riskmatrixsetupcode;
    }

    /**
     * Définit la valeur de la propriété riskmatrixsetupcode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setRISKMATRIXSETUPCODE(String value) {
        this.riskmatrixsetupcode = value;
    }

    /**
     * Obtient la valeur de la propriété description.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDESCRIPTION() {
        return description;
    }

    /**
     * Définit la valeur de la propriété description.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDESCRIPTION(String value) {
        this.description = value;
    }

}

==> eam-wshub-proxyclient-11.7-0-sources.jar: net/datastream/schemas/mp_fields/RISKMATRIXSETUPID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for RISKMATRIXSETUPID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="RISKMATRIXSETUPID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}RISKMATRIXSETUPCODE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DESCRIPTION" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "RISKMATRIXSETUPID_Type", propOrder = {
    "riskmatrixsetupcode",
    "description"
})
public class RISKMATRIXSETUPID_Type {

    @XmlElement(name = "RISKMATRIXSETUPCODE", required = true)
    protected String riskmatrixsetupcode;
    @XmlElement(name = "DESCRIPTION")
    protected String description;

    /**
     * Gets the value of the riskmatrixsetupcode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getRISKMATRIXSETUPCODE() {
        return riskmatrixsetupcode;
    }

    /**
     * Sets the value of the riskmatrixsetupcode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setRISKMATRIXSETUPCODE(String value) {
        this.riskmatrixsetupcode = value;
    }

    /**
     * Gets the value of the description property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDESCRIPTION() {
        return description;
    }

    /**
     * Sets the value of the description property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDESCRIPTION(String value) {
        this.description = value;
    }

}
